@@ -94,7 +94,6 @@ class log_in:
             if username in users:
                 if password in users:
                     self.user = username
-                    #break
                 else:
                     print(colored("Your password is incorrect", "red"))
                     log_in()
@@ -121,8 +120,9 @@ class logged_in:
     chatroom = None
     clientPusher = None
     user = None
-    
-    chatrooms = ["Python", "Java", "C#", "C++", "Javascript", "New languages", "General"]
+    #self.user = log_in.__init__()
+    #user = None
+    chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
     def __init__(self):
         print("\n")        
         print(colored("You're logged in   ", "blue"))
@@ -149,16 +149,20 @@ class logged_in:
 
     ''' This function is used to select which chatroom you would like to connect to '''
     def selectChatroom(self):
-        print("\n")        
-        print(colored("Info! Available Rooms are %s" % str(self.chatrooms), "blue"))
-        chatroom = input(colored("Please select a Room: ", "green")).capitalize()
-        if chatroom in self.chatrooms:
-            print("Please pres Ctrl+c at anytime to exit the Room")
-            self.chatroom = chatroom
-            self.initPusher()
-        else:
-            print(colored("No such Room in our list", "red"))
-            self.selectChatroom()
+        print("\n")
+        try:
+            print("Please pres Ctrl+c at anytime to exit")        
+            print(colored("Info! Available Rooms are %s" % str(self.chatrooms), "blue"))
+            chatroom = input(colored("Please select a Room: ", "green")).capitalize()
+            if chatroom in self.chatrooms:
+                print("Please pres Ctrl+c at anytime to exit the Room")
+                self.chatroom = chatroom
+                self.initPusher()
+            else:
+                print(colored("No such Room in our list", "red"))
+                self.selectChatroom()
+        except KeyboardInterrupt:
+            logged_in()
 
    
     ''' This function initialises both the Http server Pusher as well as the clientPusher'''
